@@ -1,5 +1,5 @@
 package Bio::Roary::ExtractProteomeFromGFF;
-$Bio::Roary::ExtractProteomeFromGFF::VERSION = '3.6.4';
+$Bio::Roary::ExtractProteomeFromGFF::VERSION = '3.6.5';
 # ABSTRACT: Take in a GFF file and create protein sequences in FASTA format
 
 
@@ -70,7 +70,7 @@ sub _unfiltered_output_filename {
 
 sub _create_nucleotide_fasta_file_from_gff {
     my ($self) = @_;
-    my $cmd = 'sed -n \'/##FASTA/,//p\' ' . $self->gff_file . ' | grep -v \'##FASTA\' > ' . $self->_nucleotide_fasta_file_from_gff_filename;
+    my $cmd = 'sed -n \'/^>/,//p\' ' . $self->gff_file . ' > ' . $self->_nucleotide_fasta_file_from_gff_filename;
     $self->logger->debug($cmd);
     system($cmd);
 }
@@ -107,6 +107,11 @@ sub _cleanup_fasta {
     while ( my $line = <$in> ) {
         chomp $line;
         $line =~ s/"//g if ( $line =~ /^>/ );
+	
+	if($line =~ /^(>[^:]+)/)
+	{
+		$line = $1;
+	}
         print $out "$line\n";
     }
     close $in;
@@ -196,7 +201,7 @@ Bio::Roary::ExtractProteomeFromGFF - Take in a GFF file and create protein seque
 
 =head1 VERSION
 
-version 3.6.4
+version 3.6.5
 
 =head1 SYNOPSIS
 
