@@ -1,5 +1,5 @@
 package Bio::Roary::Output::GroupsMultifastaNucleotide;
-$Bio::Roary::Output::GroupsMultifastaNucleotide::VERSION = '3.6.4';
+$Bio::Roary::Output::GroupsMultifastaNucleotide::VERSION = '3.6.5';
 # ABSTRACT:  Take in a GFF files and a groups file and output one multifasta file per group with nucleotide sequences.
 
 
@@ -111,9 +111,9 @@ sub _extracted_nucleotide_fasta_file_from_bed_filename {
 sub _create_nucleotide_fasta_file_from_gff {
     my ($self) = @_;
     my $cmd =
-        'sed -n \'/##FASTA/,//p\' '
+        'sed -n \'/^>/,//p\' '
       . $self->gff_file
-      . ' | grep -v \'##FASTA\' > '
+      . ' > '
       . $self->_nucleotide_fasta_file_from_gff_filename;
     system($cmd);
 }
@@ -165,7 +165,7 @@ Bio::Roary::Output::GroupsMultifastaNucleotide - Take in a GFF files and a group
 
 =head1 VERSION
 
-version 3.6.4
+version 3.6.5
 
 =head1 SYNOPSIS
 
